import argparse
import ccdt.video_tool.split


def get_args():
    parser = argparse.ArgumentParser('视频按帧切片（需要传入两个参数videos_dir，imgs_dir）')
    parser.add_argument('--input_dir',
                        default=r'C:/Users/54071/Desktop/55/data/rename_video_test',
                        # default='./test',
                        help='需要切片的视频路径(支持中文和英文)')
    parser.add_argument('--output_dir',
                        default=r'C:/Users/54071/Desktop/55/data/rename_video_test/output_video',
                        help='图片保存路径')
    parser.add_argument('--file_types',
                        default=['mp4', 'MP4', 'mov', 'avi', 'MOV', '264', 'dav', 'wmv'],
                        help='视频格式')
    parser.add_argument('--image_format', default='jpg', help='图片格式')
    parser.add_argument('--interval', default=50, help='几帧切一次')
    parser.add_argument('--function', type=str, help="输入操作功能参数:split只能输入单个")
    args = parser.parse_args()
    return args


def main():
    args = get_args()
    if args.function == 'split':
        videos_path, file_names = ccdt.Split.get_videos_path(args.input_dir, args.output_dir, args.file_types)
        for i in range(len(file_names)):
            ccdt.Split.save_frame(videos_path[i], args.interval, file_names[i])


if __name__ == '__main__':
    main()



import os
from collections import defaultdict


def get_auto_valid_paths(root_dir, file_formats):
    """
    最终想要组合的路径是什么样子，需要考虑一下。想要的路径如下，直接传入不改动
    dataset_info['labelme_dir']
    'Z:/4.my_work/9.zy/00/01.labelme'
    dataset_info['images_dir']
    'Z:/4.my_work/9.zy/00/00.images'
    :param root_dir:
    :param file_formats:
    :return:
    """
    files_name = []
    dir_info = defaultdict(list)
    # 使用系统方法，递归纵向遍历根路径、子路径、文件
    for root, dirs, files in os.walk(root_dir, topdown=True):
        print(root)
        print(dirs)  # 先遍历文件夹，后遍历图片，目的是想把遍历好的路径跟放到一起。
        print(files)
        # 对目录和文件进行升序排序
        dirs.sort()
        files.sort()
        # for i in dirs:
        #     print(i)
        # for file_tool in files:
        #     print(file_tool)
        # 遍历文件名称列表
        for file in files:
            print(file)
            # 获取文件后缀
            file_suffix = os.path.splitext(file)[-1]
            # 如果读取的文件后缀，在指定的后缀列表中，则返回真继续往下执行
            if file_suffix in file_formats:
                # 如果文件在文件列表中，则返回真继续往下执行
                # if file_tool in files:
                # files_name.append(file_tool)
                # create_key = os.path.join(dirs,'')
                dir_info[root.replace(root_dir, '')].append(file)
        # 如果递归遍历参数设置为假，默认设置为真传入为假，并且根路径等于传入的根路径，则返回真继续往下执行后终止递归遍历
        # if recursion is False and root == root_dir:
        # break
    return files_name


def get_valid_paths(root_dir, file_formats):
    files_name = []
    # 使用系统方法，递归纵向遍历根路径、子路径、文件
    for root, dirs, files in os.walk(root_dir, topdown=True):
        # 对目录和文件进行升序排序
        dirs.sort()
        files.sort()
        # 遍历文件名称列表
        for file in files:
            # 获取文件后缀
            file_suffix = os.path.splitext(file)[-1]
            # 如果读取的文件后缀，在指定的后缀列表中，则返回真继续往下执行
            if file_suffix in file_formats:
                # 如果文件在文件列表中，则返回真继续往下执行
                files_name.append(file)
    return files_name


def get_videos_path(input_videos_dir, output_dir, file_formats):
    """
    视频切片获取路径工具方法，暂时不用
    :param input_videos_dir:
    :param output_dir:
    :param file_formats:
    :return:
    """
    videos_path = []
    file_names = []
    # save_path = os.path.join(imgs_dir)
    if not os.path.exists(output_dir):
        os.mkdir(output_dir)
    for root, dirs, files in os.walk(input_videos_dir, topdown=False):
        # if root == videos_dir:
        #     continue
        for filename in files:
            name = filename.split('.')
            if name[1] in file_formats:
                videos_path.append(os.path.join(root, filename))
                file_names.append(os.path.join(output_dir, name[0]))
                if not os.path.exists(os.path.join(output_dir, name[0])):
                    os.mkdir(os.path.join(output_dir, name[0]))
    return videos_path, file_names



import os
import cv2


class Split(object):
    @classmethod
    def get_videos_path(cls, input_videos_dir, output_dir, file_formats):
        videos_path = []
        file_names = []
        if not os.path.exists(output_dir):
            os.mkdir(output_dir)
        for root, dirs, files in os.walk(input_videos_dir, topdown=False):
            for filename in files:
                name = filename.split('.')
                if name[1] in file_formats:
                    videos_path.append(os.path.join(root, filename))
                    file_names.append(os.path.join(output_dir, name[0]))
                    if not os.path.exists(os.path.join(output_dir, name[0])):
                        os.mkdir(os.path.join(output_dir, name[0]))
        return videos_path, file_names

    @classmethod
    def save_frame(cls, video_path, interval, output_dir):
        video = cv2.VideoCapture(video_path)
        cur_frame = 0
        num = 1
        while True:
            ret, frame = video.read()
            if not ret:
                break
            if cur_frame % int(interval) == 0:
                video_dir, video_name = os.path.split(video_path)
                video_name, extension = os.path.splitext(video_name)
                image_name = video_name + '_{:0>5d}.jpg'.format(cur_frame)
                img_dir = os.path.join(output_dir, image_name)
                cv2.imencode('.jpg', frame)[1].tofile(img_dir)
                num += 1
            cur_frame += 1
        print('视频分割完成 {}'.format(video_path))
